function B = base_act(lags,d)

% BASE_ACT   Base-level activation of instances in declarative memory.
%   ...
%   See Eq. 4.1 at p.124 of the "Atomic Components of Thought".
%   LAGS is a matrix. Each row represents an instance. Missing lags must
%   be filled with Inf.
%   When not supplied, D defaults to the global variable DECAY.
%
%   See also B_APPROX1, B_APPROX2.

%   Original coding by Alexander Petrov, Carnegie Mellon University.
%   $Revision: 1.1 $  $Date: 1999/10/22 18:30 $

%%% GLOBAL VARIABLES
global DECAY

switch nargin
  case 0
    error ('Too few input arguments to BASE_ACT.') ;
  case 1        % D defaults to the global variable DECAY
    d = DECAY ;
end

B = log(sum(lags' .^ -d)) ;

%%%%% End of BASE_ACT.M
